versionx

package
v0.0.0-...-2c4037b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package versionx extracts version information from Go build info.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(overrides ...string) string

Get returns the application version. If any non-empty override is provided, the first one is returned (useful for ldflags stamping). Otherwise it extracts the VCS revision from build info, falling back to "unknown".

func GoVersion

func GoVersion() string

GoVersion returns the Go runtime version.

Types

This section is empty.

Jump to